use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007003
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
ABEND
AFAICT
Chad
Chris
Etheridge
Formattable
Granum
Gratipay
Karen
Moose
More
RSRCHBOY
RSRCHBOY's
Test
Weyl
chad
codebase
coderef
cweyl
ether
formattable
gpg
implementers
ini
lib
metaclass
metaclasses
parameterization
parameterized
subclasses
